import 'package:flutter/material.dart';
import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:minehunter/common/cubit/nav/nav_cubit_pages.dart';

import 'package:minehunter/cubit/activity/activity_cubit.dart';
import 'package:minehunter/ui/parameters/parameter_painter_board_size.dart';
import 'package:minehunter/ui/parameters/parameter_painter_difficulty_level.dart';

class ApplicationConfig {
  static const String parameterCodeSkin = 'global.skin';
  static const String parameterCodeDifficultyLevel = 'level';
  static const String parameterCodeBoardSize = 'size';

  static const String skinValueDefault = 'default';

  static const String difficultyLevelValueEasy = 'easy';
  static const String difficultyLevelValueMedium = 'medium';
  static const String difficultyLevelValueHard = 'hard';
  static const String difficultyLevelValueNightmare = 'nightmare';

  static const String boardSizeValueSmall = '10x10';
  static const String boardSizeValueMedium = '15x15';
  static const String boardSizeValueLarge = '20x20';
  static const String boardSizeValueExtraLarge = '25x25';

  static final ApplicationConfigDefinition config = ApplicationConfigDefinition(
    appTitle: 'Minehunter',
    activitySettings: [
      // skin
      ApplicationSettingsParameter(
        code: parameterCodeSkin,
        values: [
          ApplicationSettingsParameterItemValue(
            value: skinValueDefault,
            isDefault: true,
          ),
        ],
      ),

      // difficulty level
      ApplicationSettingsParameter(
        code: parameterCodeDifficultyLevel,
        values: [
          ApplicationSettingsParameterItemValue(
            value: difficultyLevelValueEasy,
            color: Colors.green,
          ),
          ApplicationSettingsParameterItemValue(
            value: difficultyLevelValueMedium,
            color: Colors.orange,
            isDefault: true,
          ),
          ApplicationSettingsParameterItemValue(
            value: difficultyLevelValueHard,
            color: Colors.red,
          ),
          ApplicationSettingsParameterItemValue(
            value: difficultyLevelValueNightmare,
            color: Colors.purple,
          ),
        ],
        customPainter: (context, value) => ParameterPainterDifficultyLevel(
          context: context,
          value: value,
        ),
      ),

      // board size
      ApplicationSettingsParameter(
        code: parameterCodeBoardSize,
        values: [
          ApplicationSettingsParameterItemValue(
            value: boardSizeValueSmall,
            color: Colors.green,
          ),
          ApplicationSettingsParameterItemValue(
            value: boardSizeValueMedium,
            color: Colors.orange,
            isDefault: true,
          ),
          ApplicationSettingsParameterItemValue(
            value: boardSizeValueLarge,
            color: Colors.red,
          ),
          ApplicationSettingsParameterItemValue(
            value: boardSizeValueExtraLarge,
            color: Colors.purple,
          ),
        ],
        customPainter: (context, value) => ParameterPainterBoardSize(
          context: context,
          value: value,
        ),
      ),
    ],
    startNewActivity: (BuildContext context) {
      BlocProvider.of<ActivityCubit>(context).startNewActivity(context);
      BlocProvider.of<NavCubitPage>(context).goToPageGame();
    },
    deleteCurrentActivity: (BuildContext context) {
      BlocProvider.of<ActivityCubit>(context).deleteSavedActivity();
    },
    resumeActivity: (BuildContext context) {
      BlocProvider.of<ActivityCubit>(context).resumeSavedActivity();
      BlocProvider.of<NavCubitPage>(context).goToPageGame();
    },
  );

  // how many mines? (per 100 tiles)
  static const Map<String, int> minesCountRatios = {
    ApplicationConfig.difficultyLevelValueEasy: 5,
    ApplicationConfig.difficultyLevelValueMedium: 10,
    ApplicationConfig.difficultyLevelValueHard: 15,
    ApplicationConfig.difficultyLevelValueNightmare: 20,
  };
}
